@@ -6,6 +6,7 @@ from pathlib import Path
 import pytest
 
 from pdm.pep517 import api
+from pdm.pep517.wheel import WheelBuilder
 from tests.testutils import build_fixture_project, get_tarball_names, get_wheel_names
 
 
@@ -35,7 +36,7 @@ def test_build_single_module(tmp_path: Path) -> None:
         for name in ("pyproject.toml", "LICENSE"):
             assert name not in zip_names
 
-        assert "demo_module-0.1.0.dist-info/license_files/LICENSE" in zip_names
+        assert "demo_module-0.1.0.dist-info/licenses/LICENSE" in zip_names
 
 
 def test_build_package(tmp_path: Path) -> None:
@@ -199,7 +200,7 @@ def test_build_editable(tmp_path: Path) -> None:
             namelist = zf.namelist()
             assert "demo_package.pth" in namelist
             assert "__editables_demo_package.py" in namelist
-            assert "demo_package-0.1.0.dist-info/license_files/LICENSE" in namelist
+            assert "demo_package-0.1.0.dist-info/licenses/LICENSE" in namelist
 
             metadata = email.message_from_bytes(
                 zf.read("demo_package-0.1.0.dist-info/METADATA")
@@ -289,6 +290,8 @@ def test_build_purelib_project_with_build(tmp_path: Path) -> None:
             wheel_metadata = email.message_from_bytes(
                 zf.read("demo_package-0.1.0.dist-info/WHEEL")
             )
+            version = zf.read("my_package/version.foo").decode("utf-8").strip()
+            assert version == "0.1.0"
             assert wheel_metadata["Root-Is-Purelib"] == "True"
 
 
@@ -302,3 +305,30 @@ def test_build_wheel_preserve_permission(tmp_path: Path) -> None:
             info = zf.getinfo("my_package/executable")
             filemode = info.external_attr >> 16
             assert filemode & 0o111
+
+
+def test_build_wheel_write_version_to_file(project_with_scm: Path) -> None:
+    builder = WheelBuilder(project_with_scm)
+    builder.meta.config.data["version"] = {
+        "source": "scm",
+        "write_to": "foo/__version__.py",
+    }
+    with builder:
+        wheel_name = builder.build(project_with_scm / "dist")
+        with zipfile.ZipFile(project_with_scm / wheel_name) as zf:
+            version = zf.read("foo/__version__.py").decode("utf-8").strip()
+            assert version == "0.1.0"
+
+
+def test_build_wheel_write_version_to_file_template(project_with_scm: Path) -> None:
+    builder = WheelBuilder(project_with_scm)
+    builder.meta.config.data["version"] = {
+        "source": "scm",
+        "write_to": "foo/__version__.py",
+        "write_template": '__version__ = "{}"\n',
+    }
+    with builder:
+        wheel_name = builder.build(project_with_scm / "dist")
+        with zipfile.ZipFile(project_with_scm / wheel_name) as zf:
+            version = zf.read("foo/__version__.py").decode("utf-8").strip()
+            assert version == '__version__ = "0.1.0"'
